@@ -19,6 +19,7 @@ from datetime import datetime, date
 
 import inflection
 
+from .validation import *
 from firefly.domain.meta.entity_meta import EntityMeta
 from firefly.domain.value_object import ValueObject
 from firefly.domain.meta.context_aware import ContextAware
@@ -117,6 +118,92 @@ class Entity(ContextAware, ValueObject):
         if id_name in args:
             return {id_name: args[id_name]}
 
+    @classmethod
+    def get_dto_schema(cls):
+        ret = {
+            '$schema': 'http://json-schema.org/draft-07/schema#',
+            'title': cls.__name__,
+            'type': 'object',
+        }
+
+        mappings = {
+            str: 'string',
+            int: 'integer',
+            float: 'number',
+            bool: 'boolean',
+            datetime: 'string',
+            date: 'string',
+        }
+
+        types_ = typing.get_type_hints(cls)
+        props = {}
+        required_fields = []
+        for field_ in fields(cls):
+            if field_.name.startswith('_'):
+                continue
+
+            if 'hidden' in field_.metadata and field_.metadata['hidden'] is True:
+                continue
+
+            prop = {
+                'title': field_.metadata.get('title') or inflection.humanize(field_.name),
+            }
+            t = types_[field_.name]
+            if t in mappings:
+                if t in mappings:
+                    prop['type'] = mappings[t]
+
+            if 'validators' in field_.metadata:
+                for validator in field_.metadata['validators']:
+                    if isinstance(validator, IsValidEmail):
+                        prop['format'] = 'email'
+                    elif isinstance(validator, HasLength):
+                        prop['minLength'] = validator.length
+                        prop['maxLength'] = validator.length
+                    elif isinstance(validator, MatchesPattern):
+                        prop['pattern'] = validator.regex
+                    elif isinstance(validator, IsValidUrl):
+                        prop['format'] = 'uri'
+                    elif isinstance(validator, IsLessThanOrEqualTo):
+                        prop['maximum'] = validator.value
+                    elif isinstance(validator, IsLessThan):
+                        prop['maximum'] = validator.value
+                        prop['exclusiveMaximum'] = True
+                    elif isinstance(validator, IsGreaterThanOrEqualTo):
+                        prop['minimum'] = validator.value
+                    elif isinstance(validator, IsGreaterThan):
+                        prop['minimum'] = validator.value
+                        prop['exclusiveMinimum'] = True
+                    elif isinstance(validator, IsMultipleOf):
+                        prop['multipleOf'] = validator.value
+                    elif isinstance(validator, HasMaxLength):
+                        prop['maxLength'] = validator.length
+                    elif isinstance(validator, HasMinLength):
+                        prop['minLength'] = validator.length
+
+            if t is datetime:
+                prop['format'] = 'date-time'
+            elif t is date:
+                prop['format'] = 'date'
+
+            if 'format' in field_.metadata:
+                prop['format'] = field_.metadata.get('format')
+
+            if 'required' in field_.metadata and field_.metadata['required'] is True:
+                try:
+                    if isinstance(field_.default_factory(), Empty):
+                        required_fields.append(field_.name)
+                except TypeError:
+                    required_fields.append(field_.name)
+
+            props[field_.name] = prop
+
+        ret['properties'] = props
+        if len(required_fields) > 0:
+            ret['required'] = required_fields
+
+        return ret
+
     def debug(self, *args, **kwargs):
         return self._logger.debug(*args, **kwargs)
 
