@@ -26,11 +26,15 @@ T = TypeVar('T')
 
 class QueryService(Generic[T], GenericBase, ApplicationService):
     _registry: ffd.Registry = None
+    _serializer: ffd.Serializer = None
 
     def __call__(self, **kwargs):
         try:
             if 'criteria' in kwargs:
-                return self._registry(self._type()).filter(ffd.BinaryOp.from_dict(kwargs['criteria']))
+                criteria = kwargs['criteria']
+                if isinstance(criteria, str):
+                    criteria = self._serializer.deserialize(criteria)
+                return self._registry(self._type()).filter(ffd.BinaryOp.from_dict(criteria))
             else:
                 return list(self._registry(self._type()))
         except KeyError:
